pub struct SymbolContext {
pub node: NodeSummary,
pub container: Option<String>,
pub calls: Vec<String>,
pub called_by: Vec<String>,
pub authored_by: Vec<String>,
}Expand description
A code symbol related to the topic, with the slice of its graph neighbourhood that grounds authoring: what defines it, what it calls / is called by, and the authored ADRs/sections that govern it.
Fields
node: NodeSummaryThe symbol node.
container: Option<String>Key of the node that contains/defines it (its file or parent), if any.
calls: Vec<String>Keys this symbol calls.
called_by: Vec<String>Keys that call this symbol.
Keys of ADR/section nodes with an authored edge to this symbol.